Readable

Trait Readable 

pub trait Readable: RegisterSpec {
    type Reader: From<R<Self>> + Deref<Target = R<Self>>;
}
Trait implemented by readable registers to enable the read method.

Registers marked with Writable can be also be modify’ed.

Required Associated Types

type Reader: From<R<Self>> + Deref<Target = R<Self>>

Result from a call to read and argument to modify.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl Readable for bl616_pac::agc::todo::TODO_SPEC

read() method returns todo::R reader structure

Source

impl Readable for ANALOG_0_SPEC

read() method returns analog_0::R reader structure

Source

impl Readable for ANALOG_1_SPEC

read() method returns analog_1::R reader structure

Source

impl Readable for bl616_pac::auadc::clock::CLOCK_SPEC

read() method returns clock::R reader structure

Source

impl Readable for COMMAND_SPEC

read() method returns command::R reader structure

Source

impl Readable for bl616_pac::auadc::fifo_control::FIFO_CONTROL_SPEC

read() method returns fifo_control::R reader structure

Source

impl Readable for bl616_pac::auadc::fifo_data::FIFO_DATA_SPEC

read() method returns fifo_data::R reader structure

Source

impl Readable for bl616_pac::auadc::fifo_state::FIFO_STATE_SPEC

read() method returns fifo_state::R reader structure

Source

impl Readable for FINITE_IMPULSE_SPEC

read() method returns finite_impulse::R reader structure

Source

impl Readable for HIGH_PASS_SPEC

read() method returns high_pass::R reader structure

Source

impl Readable for INTERFACE_0_SPEC

read() method returns interface_0::R reader structure

Source

impl Readable for INTERFACE_1_SPEC

read() method returns interface_1::R reader structure

Source

impl Readable for PULSE_WIDTH_SPEC

read() method returns pulse_width::R reader structure

Source

impl Readable for SAMPLE_DATA_SPEC

read() method returns sample_data::R reader structure

Source

impl Readable for VOLUME_SPEC

read() method returns volume::R reader structure

Source

impl Readable for bl616_pac::audac::clock::CLOCK_SPEC

read() method returns clock::R reader structure

Source

impl Readable for bl616_pac::audac::config::CONFIG_SPEC

read() method returns config::R reader structure

Source

impl Readable for bl616_pac::audac::fifo_control::FIFO_CONTROL_SPEC

read() method returns fifo_control::R reader structure

Source

impl Readable for bl616_pac::audac::fifo_data::FIFO_DATA_SPEC

read() method returns fifo_data::R reader structure

Source

impl Readable for bl616_pac::audac::fifo_state::FIFO_STATE_SPEC

read() method returns fifo_state::R reader structure

Source

impl Readable for STATE_SPEC

read() method returns state::R reader structure

Source

impl Readable for VOLUME_0_SPEC

read() method returns volume_0::R reader structure

Source

impl Readable for VOLUME_1_SPEC

read() method returns volume_1::R reader structure

Source

impl Readable for ZERO_SIGNAL_SPEC

read() method returns zero_signal::R reader structure

Source

impl Readable for bl616_pac::crc::config::CONFIG_SPEC

read() method returns config::R reader structure

Source

impl Readable for OUTPUT_SPEC

read() method returns output::R reader structure

Source

impl Readable for bl616_pac::dbi::todo::TODO_SPEC

read() method returns todo::R reader structure

Source

impl Readable for BURST_REQUEST_SPEC

read() method returns burst_request::R reader structure

Source

impl Readable for bl616_pac::dma::channel::config::CONFIG_SPEC

read() method returns config::R reader structure

Source

impl Readable for bl616_pac::dma::channel::control::CONTROL_SPEC

read() method returns control::R reader structure

Source

impl Readable for DESTINATION_SPEC

read() method returns destination::R reader structure

Source

impl Readable for LINKED_LIST_SPEC

read() method returns linked_list::R reader structure

Source

impl Readable for SOURCE_SPEC

read() method returns source::R reader structure

Source

impl Readable for CHANNEL_STATE_SPEC

read() method returns channel_state::R reader structure

Source

impl Readable for bl616_pac::dma::config::CONFIG_SPEC

read() method returns config::R reader structure

Source

impl Readable for ERROR_CLEAR_SPEC

read() method returns error_clear::R reader structure

Source

impl Readable for ERROR_STATE_SPEC

read() method returns error_state::R reader structure

Source

impl Readable for ERROR_STATE_RAW_SPEC

read() method returns error_state_raw::R reader structure

Source

impl Readable for bl616_pac::dma::interrupt_state::INTERRUPT_STATE_SPEC

read() method returns interrupt_state::R reader structure

Source

impl Readable for LAST_BURST_REQUEST_SPEC

read() method returns last_burst_request::R reader structure

Source

impl Readable for LAST_SINGLE_REQUEST_SPEC

read() method returns last_single_request::R reader structure

Source

impl Readable for SINGLE_REQUEST_SPEC

read() method returns single_request::R reader structure

Source

impl Readable for SYNCHRONIZE_SPEC

read() method returns synchronize::R reader structure

Source

impl Readable for TERMINATE_CLEAR_SPEC

read() method returns terminate_clear::R reader structure

Source

impl Readable for TERMINATE_STATE_SPEC

read() method returns terminate_state::R reader structure

Source

impl Readable for TERMINATE_STATE_RAW_SPEC

read() method returns terminate_state_raw::R reader structure

Source

impl Readable for bl616_pac::dvp::todo::TODO_SPEC

read() method returns todo::R reader structure

Source

impl Readable for bl616_pac::efuse::todo::TODO_SPEC

read() method returns todo::R reader structure

Source

impl Readable for BACKED_GAP_SPEC

read() method returns backed_gap::R reader structure

Source

impl Readable for COLLISION_SPEC

read() method returns collision::R reader structure

Source

impl Readable for CONTROL_READ_SPEC

read() method returns control_read::R reader structure

Source

impl Readable for CONTROL_WRITE_SPEC

read() method returns control_write::R reader structure

Source

impl Readable for FLOW_CONTROL_SPEC

read() method returns flow_control::R reader structure

Source

impl Readable for FRAME_LENGTH_SPEC

read() method returns frame_length::R reader structure

Source

impl Readable for HASH_SPEC

read() method returns hash::R reader structure

Source

impl Readable for bl616_pac::emac::interrupt_mask::INTERRUPT_MASK_SPEC

read() method returns interrupt_mask::R reader structure

Source

impl Readable for INTERRUPT_SOURCE_SPEC

read() method returns interrupt_source::R reader structure

Source

impl Readable for MAC_ADDRESS_SPEC

read() method returns mac_address::R reader structure

Source

impl Readable for MII_ADDRESS_SPEC

read() method returns mii_address::R reader structure

Source

impl Readable for MII_COMMAND_SPEC

read() method returns mii_command::R reader structure

Source

impl Readable for MII_MODE_SPEC

read() method returns mii_mode::R reader structure

Source

impl Readable for MII_STATE_SPEC

read() method returns mii_state::R reader structure

Source

impl Readable for MODE_SPEC

read() method returns mode::R reader structure

Source

impl Readable for NON_BACKED_GAP_1_SPEC

read() method returns non_backed_gap_1::R reader structure

Source

impl Readable for NON_BACKED_GAP_2_SPEC

read() method returns non_backed_gap_2::R reader structure

Source

impl Readable for TRANSMIT_BUFFER_SPEC

read() method returns transmit_buffer::R reader structure

Source

impl Readable for TRANSMIT_CONTROL_SPEC

read() method returns transmit_control::R reader structure

Source

impl Readable for bl616_pac::flash::todo::TODO_SPEC

read() method returns todo::R reader structure

Source

impl Readable for AUDIO_CONFIG_0_SPEC

read() method returns audio_config_0::R reader structure

Source

impl Readable for AUDIO_CONFIG_1_SPEC

read() method returns audio_config_1::R reader structure

Source

impl Readable for BUS_CONFIG_0_SPEC

read() method returns bus_config_0::R reader structure

Source

impl Readable for CHIP_INFORM_SPEC

read() method returns chip_inform::R reader structure

Source

impl Readable for CLOCK_CONFIG_0_SPEC

read() method returns clock_config_0::R reader structure

Source

impl Readable for CLOCK_CONFIG_1_SPEC

read() method returns clock_config_1::R reader structure

Source

impl Readable for DBI_CONFIG_SPEC

read() method returns dbi_config::R reader structure

Source

impl Readable for DEBUG_CONFIG_0_SPEC

read() method returns debug_config_0::R reader structure

Source

impl Readable for DEBUG_CONFIG_1_SPEC

read() method returns debug_config_1::R reader structure

Source

impl Readable for DEBUG_CONFIG_2_SPEC

read() method returns debug_config_2::R reader structure

Source

impl Readable for DEBUG_CONFIG_3_SPEC

read() method returns debug_config_3::R reader structure

Source

impl Readable for DEBUG_CONFIG_4_SPEC

read() method returns debug_config_4::R reader structure

Source

impl Readable for DIGIT_CLOCK_0_SPEC

read() method returns digit_clock_0::R reader structure

Source

impl Readable for DIGIT_CLOCK_1_SPEC

read() method returns digit_clock_1::R reader structure

Source

impl Readable for DIGIT_CLOCK_2_SPEC

read() method returns digit_clock_2::R reader structure

Source

impl Readable for DMA_CONFIG_0_SPEC

read() method returns dma_config_0::R reader structure

Source

impl Readable for DMA_CONFIG_1_SPEC

read() method returns dma_config_1::R reader structure

Source

impl Readable for DMA_CONFIG_2_SPEC

read() method returns dma_config_2::R reader structure

Source

impl Readable for EMAC_CONFIG_SPEC

read() method returns emac_config::R reader structure

Source

impl Readable for FLASH_CONFIG_SPEC

read() method returns flash_config::R reader structure

Source

impl Readable for bl616_pac::glb::gpadc_config::GPADC_CONFIG_SPEC

read() method returns gpadc_config::R reader structure

Source

impl Readable for GPDAC_CONFIG_0_SPEC

read() method returns gpdac_config_0::R reader structure

Source

impl Readable for GPDAC_CONFIG_1_SPEC

read() method returns gpdac_config_1::R reader structure

Source

impl Readable for GPDAC_CONFIG_2_SPEC

read() method returns gpdac_config_2::R reader structure

Source

impl Readable for GPDAC_CONFIG_3_SPEC

read() method returns gpdac_config_3::R reader structure

Source

impl Readable for GPIO_CLEAR_SPEC

read() method returns gpio_clear::R reader structure

Source

impl Readable for GPIO_CONFIG_SPEC

read() method returns gpio_config::R reader structure

Source

impl Readable for GPIO_INPUT_SPEC

read() method returns gpio_input::R reader structure

Source

impl Readable for GPIO_OUTPUT_SPEC

read() method returns gpio_output::R reader structure

Source

impl Readable for GPIO_SET_SPEC

read() method returns gpio_set::R reader structure

Source

impl Readable for I2C_CONFIG_SPEC

read() method returns i2c_config::R reader structure

Source

impl Readable for I2S_CONFIG_SPEC

read() method returns i2s_config::R reader structure

Source

impl Readable for bl616_pac::glb::interrupt_clear::INTERRUPT_CLEAR_SPEC

read() method returns interrupt_clear::R reader structure

Source

impl Readable for bl616_pac::glb::interrupt_mask::INTERRUPT_MASK_SPEC

read() method returns interrupt_mask::R reader structure

Source

impl Readable for bl616_pac::glb::interrupt_state::INTERRUPT_STATE_SPEC

read() method returns interrupt_state::R reader structure

Source

impl Readable for IR_CONFIG_0_SPEC

read() method returns ir_config_0::R reader structure

Source

impl Readable for IR_CONFIG_1_SPEC

read() method returns ir_config_1::R reader structure

Source

impl Readable for LDO18_SPEC

read() method returns ldo18::R reader structure

Source

impl Readable for PERMIT_CONFIG_SPEC

read() method returns permit_config::R reader structure

Source

impl Readable for PSRAM_CONFIG_SPEC

read() method returns psram_config::R reader structure

Source

impl Readable for PWM_CONFIG_SPEC

read() method returns pwm_config::R reader structure

Source

impl Readable for RADIO_CONFIG_SPEC

read() method returns radio_config::R reader structure

Source

impl Readable for SDH_CONFIG_SPEC

read() method returns sdh_config::R reader structure

Source

impl Readable for SELF_TEST_0_SPEC

read() method returns self_test_0::R reader structure

Source

impl Readable for SELF_TEST_1_SPEC

read() method returns self_test_1::R reader structure

Source

impl Readable for SPI_CONFIG_SPEC

read() method returns spi_config::R reader structure

Source

impl Readable for UART_CONFIG_SPEC

read() method returns uart_config::R reader structure

Source

impl Readable for UART_SIGNAL_0_SPEC

read() method returns uart_signal_0::R reader structure

Source

impl Readable for UART_SIGNAL_1_SPEC

read() method returns uart_signal_1::R reader structure

Source

impl Readable for WIFI_PLL_CONFIG_0_SPEC

read() method returns wifi_pll_config_0::R reader structure

Source

impl Readable for WIFI_PLL_CONFIG_1_SPEC

read() method returns wifi_pll_config_1::R reader structure

Source

impl Readable for WIFI_PLL_CONFIG_2_SPEC

read() method returns wifi_pll_config_2::R reader structure

Source

impl Readable for WIFI_PLL_CONFIG_3_SPEC

read() method returns wifi_pll_config_3::R reader structure

Source

impl Readable for WIFI_PLL_CONFIG_4_SPEC

read() method returns wifi_pll_config_4::R reader structure

Source

impl Readable for WIFI_PLL_CONFIG_5_SPEC

read() method returns wifi_pll_config_5::R reader structure

Source

impl Readable for WIFI_PLL_CONFIG_6_SPEC

read() method returns wifi_pll_config_6::R reader structure

Source

impl Readable for WIFI_PLL_CONFIG_7_SPEC

read() method returns wifi_pll_config_7::R reader structure

Source

impl Readable for WIFI_PLL_CONFIG_8_SPEC

read() method returns wifi_pll_config_8::R reader structure

Source

impl Readable for WIFI_PLL_CONFIG_9_SPEC

read() method returns wifi_pll_config_9::R reader structure

Source

impl Readable for WIFI_PLL_CONFIG_10_SPEC

read() method returns wifi_pll_config_10::R reader structure

Source

impl Readable for WIFI_PLL_CONFIG_11_SPEC

read() method returns wifi_pll_config_11::R reader structure

Source

impl Readable for WIFI_PLL_CONFIG_12_SPEC

read() method returns wifi_pll_config_12::R reader structure

Source

impl Readable for WIFI_PLL_CONFIG_13_SPEC

read() method returns wifi_pll_config_13::R reader structure

Source

impl Readable for WIFI_PLL_CONFIG_14_SPEC

read() method returns wifi_pll_config_14::R reader structure

Source

impl Readable for bl616_pac::gpip::gpadc_config::GPADC_CONFIG_SPEC

read() method returns gpadc_config::R reader structure

Source

impl Readable for GPADC_DMA_READ_SPEC

read() method returns gpadc_dma_read::R reader structure

Source

impl Readable for GPDAC_CONFIG_SPEC

read() method returns gpdac_config::R reader structure

Source

impl Readable for GPDAC_DMA_CONFIG_SPEC

read() method returns gpdac_dma_config::R reader structure

Source

impl Readable for GPDAC_DMA_WRITE_SPEC

read() method returns gpdac_dma_write::R reader structure

Source

impl Readable for GPDAC_FIFO_STATE_SPEC

read() method returns gpdac_fifo_state::R reader structure

Source

impl Readable for bl616_pac::hbn::control::CONTROL_SPEC

read() method returns control::R reader structure

Source

impl Readable for GLOBAL_SPEC

read() method returns global::R reader structure

Source

impl Readable for bl616_pac::hbn::interrupt_clear::INTERRUPT_CLEAR_SPEC

read() method returns interrupt_clear::R reader structure

Source

impl Readable for INTERRUPT_MODE_SPEC

read() method returns interrupt_mode::R reader structure

Source

impl Readable for bl616_pac::hbn::interrupt_state::INTERRUPT_STATE_SPEC

read() method returns interrupt_state::R reader structure

Source

impl Readable for RC32K_SPEC

read() method returns rc32k::R reader structure

Source

impl Readable for RTC_CONTROL_0_SPEC

read() method returns rtc_control_0::R reader structure

Source

impl Readable for RTC_CONTROL_1_SPEC

read() method returns rtc_control_1::R reader structure

Source

impl Readable for RTC_TIME_HI_SPEC

read() method returns rtc_time_hi::R reader structure

Source

impl Readable for RTC_TIME_LO_SPEC

read() method returns rtc_time_lo::R reader structure

Source

impl Readable for SRAM_SPEC

read() method returns sram::R reader structure

Source

impl Readable for TIME_HI_SPEC

read() method returns time_hi::R reader structure

Source

impl Readable for TIME_LO_SPEC

read() method returns time_lo::R reader structure

Source

impl Readable for XTAL32K_SPEC

read() method returns xtal32k::R reader structure

Source

impl Readable for bl616_pac::i2c::bus_busy::BUS_BUSY_SPEC

read() method returns bus_busy::R reader structure

Source

impl Readable for bl616_pac::i2c::config::CONFIG_SPEC

read() method returns config::R reader structure

Source

impl Readable for bl616_pac::i2c::data_read::DATA_READ_SPEC

read() method returns data_read::R reader structure

Source

impl Readable for bl616_pac::i2c::fifo_config_0::FIFO_CONFIG_0_SPEC

read() method returns fifo_config_0::R reader structure

Source

impl Readable for bl616_pac::i2c::fifo_config_1::FIFO_CONFIG_1_SPEC

read() method returns fifo_config_1::R reader structure

Source

impl Readable for INTERRUPT_SPEC

read() method returns interrupt::R reader structure

Source

impl Readable for PERIOD_DATA_SPEC

read() method returns period_data::R reader structure

Source

impl Readable for PERIOD_START_SPEC

read() method returns period_start::R reader structure

Source

impl Readable for PERIOD_STOP_SPEC

read() method returns period_stop::R reader structure

Source

impl Readable for SUB_ADDRESS_SPEC

read() method returns sub_address::R reader structure

Source

impl Readable for BASE_CLOCK_SPEC

read() method returns base_clock::R reader structure

Source

impl Readable for bl616_pac::i2s::config::CONFIG_SPEC

read() method returns config::R reader structure

Source

impl Readable for bl616_pac::i2s::data_read::DATA_READ_SPEC

read() method returns data_read::R reader structure

Source

impl Readable for bl616_pac::i2s::fifo_config_0::FIFO_CONFIG_0_SPEC

read() method returns fifo_config_0::R reader structure

Source

impl Readable for bl616_pac::i2s::fifo_config_1::FIFO_CONFIG_1_SPEC

read() method returns fifo_config_1::R reader structure

Source

impl Readable for bl616_pac::i2s::interrupt_state::INTERRUPT_STATE_SPEC

read() method returns interrupt_state::R reader structure

Source

impl Readable for RECEIVE_BIT_COUNT_SPEC

read() method returns receive_bit_count::R reader structure

Source

impl Readable for bl616_pac::ir::receive_config::RECEIVE_CONFIG_SPEC

read() method returns receive_config::R reader structure

Source

impl Readable for RECEIVE_DATA_SPEC

read() method returns receive_data::R reader structure

Source

impl Readable for RECEIVE_INTERRUPT_SPEC

read() method returns receive_interrupt::R reader structure

Source

impl Readable for RECEIVE_WIDTH_SPEC

read() method returns receive_width::R reader structure

Source

impl Readable for bl616_pac::ir::transmit_config::TRANSMIT_CONFIG_SPEC

read() method returns transmit_config::R reader structure

Source

impl Readable for TRANSMIT_DATA_SPEC

read() method returns transmit_data::R reader structure

Source

impl Readable for TRANSMIT_INTERRUPT_SPEC

read() method returns transmit_interrupt::R reader structure

Source

impl Readable for TRANSMIT_WIDTH_SPEC

read() method returns transmit_width::R reader structure

Source

impl Readable for bl616_pac::iso11898::todo::TODO_SPEC

read() method returns todo::R reader structure

Source

impl Readable for bl616_pac::mjpeg::todo::TODO_SPEC

read() method returns todo::R reader structure

Source

impl Readable for TOUCH_CHANNEL_SPEC

read() method returns touch_channel::R reader structure

Source

impl Readable for TOUCH_CONFIG_SPEC

read() method returns touch_config::R reader structure

Source

impl Readable for TOUCH_DELAY_SPEC

read() method returns touch_delay::R reader structure

Source

impl Readable for TOUCH_FORCE_SPEC

read() method returns touch_force::R reader structure

Source

impl Readable for TOUCH_INTERRUPT_0_SPEC

read() method returns touch_interrupt_0::R reader structure

Source

impl Readable for TOUCH_INTERRUPT_1_SPEC

read() method returns touch_interrupt_1::R reader structure

Source

impl Readable for TOUCH_PROCESS_SPEC

read() method returns touch_process::R reader structure

Source

impl Readable for TOUCH_RAW_SPEC

read() method returns touch_raw::R reader structure

Source

impl Readable for TOUCH_SLEEP_SPEC

read() method returns touch_sleep::R reader structure

Source

impl Readable for TOUCH_VOLTAGE_SPEC

read() method returns touch_voltage::R reader structure

Source

impl Readable for bl616_pac::permit::todo::TODO_SPEC

read() method returns todo::R reader structure

Source

impl Readable for bl616_pac::psram::todo::TODO_SPEC

read() method returns todo::R reader structure

Source

impl Readable for CHANNEL_SPEC

read() method returns channel::R reader structure

Source

impl Readable for bl616_pac::pwm::group::config::CONFIG_SPEC

read() method returns config::R reader structure

Source

impl Readable for DEAD_TIME_SPEC

read() method returns dead_time::R reader structure

Source

impl Readable for bl616_pac::pwm::group::interrupt_enable::INTERRUPT_ENABLE_SPEC

read() method returns interrupt_enable::R reader structure

Source

impl Readable for bl616_pac::pwm::group::interrupt_mask::INTERRUPT_MASK_SPEC

read() method returns interrupt_mask::R reader structure

Source

impl Readable for bl616_pac::pwm::group::interrupt_state::INTERRUPT_STATE_SPEC

read() method returns interrupt_state::R reader structure

Source

impl Readable for PERIOD_SPEC

read() method returns period::R reader structure

Source

impl Readable for THRESHOLD_SPEC

read() method returns threshold::R reader structure

Source

impl Readable for INTERRUPT_CONFIG_SPEC

read() method returns interrupt_config::R reader structure

Source

impl Readable for bl616_pac::sdh::todo::TODO_SPEC

read() method returns todo::R reader structure

Source

impl Readable for bl616_pac::sdu::todo::TODO_SPEC

read() method returns todo::R reader structure

Source

impl Readable for bl616_pac::sec::todo::TODO_SPEC

read() method returns todo::R reader structure

Source

impl Readable for bl616_pac::spi::bus_busy::BUS_BUSY_SPEC

read() method returns bus_busy::R reader structure

Source

impl Readable for bl616_pac::spi::config::CONFIG_SPEC

read() method returns config::R reader structure

Source

impl Readable for bl616_pac::spi::data_read::DATA_READ_SPEC

read() method returns data_read::R reader structure

Source

impl Readable for DATA_WRITE_SPEC

read() method returns data_write::R reader structure

Source

impl Readable for bl616_pac::spi::fifo_config_0::FIFO_CONFIG_0_SPEC

read() method returns fifo_config_0::R reader structure

Source

impl Readable for bl616_pac::spi::fifo_config_1::FIFO_CONFIG_1_SPEC

read() method returns fifo_config_1::R reader structure

Source

impl Readable for IGNORE_INDEX_SPEC

read() method returns ignore_index::R reader structure

Source

impl Readable for bl616_pac::spi::interrupt_state::INTERRUPT_STATE_SPEC

read() method returns interrupt_state::R reader structure

Source

impl Readable for PERIOD_CONTROL_SPEC

read() method returns period_control::R reader structure

Source

impl Readable for PERIOD_INTERVAL_SPEC

read() method returns period_interval::R reader structure

Source

impl Readable for TIMEOUT_SPEC

read() method returns timeout::R reader structure

Source

impl Readable for bl616_pac::timer::todo::TODO_SPEC

read() method returns todo::R reader structure

Source

impl Readable for AUTO_BAUDRATE_SPEC

read() method returns auto_baudrate::R reader structure

Source

impl Readable for BIT_PERIOD_SPEC

read() method returns bit_period::R reader structure

Source

impl Readable for BUS_STATE_SPEC

read() method returns bus_state::R reader structure

Source

impl Readable for DATA_CONFIG_SPEC

read() method returns data_config::R reader structure

Source

impl Readable for bl616_pac::uart::data_read::DATA_READ_SPEC

read() method returns data_read::R reader structure

Source

impl Readable for bl616_pac::uart::fifo_config_0::FIFO_CONFIG_0_SPEC

read() method returns fifo_config_0::R reader structure

Source

impl Readable for bl616_pac::uart::fifo_config_1::FIFO_CONFIG_1_SPEC

read() method returns fifo_config_1::R reader structure

Source

impl Readable for bl616_pac::uart::interrupt_enable::INTERRUPT_ENABLE_SPEC

read() method returns interrupt_enable::R reader structure

Source

impl Readable for bl616_pac::uart::interrupt_mask::INTERRUPT_MASK_SPEC

read() method returns interrupt_mask::R reader structure

Source

impl Readable for bl616_pac::uart::interrupt_state::INTERRUPT_STATE_SPEC

read() method returns interrupt_state::R reader structure

Source

impl Readable for PULSE_TOLERANCE_SPEC

read() method returns pulse_tolerance::R reader structure

Source

impl Readable for bl616_pac::uart::receive_config::RECEIVE_CONFIG_SPEC

read() method returns receive_config::R reader structure

Source

impl Readable for RECEIVE_POSITION_SPEC

read() method returns receive_position::R reader structure

Source

impl Readable for RECEIVE_TIMEOUT_SPEC

read() method returns receive_timeout::R reader structure

Source

impl Readable for RS485_TRANSMIT_SPEC

read() method returns rs485_transmit::R reader structure

Source

impl Readable for SIGNAL_OVERRIDE_SPEC

read() method returns signal_override::R reader structure

Source

impl Readable for bl616_pac::uart::transmit_config::TRANSMIT_CONFIG_SPEC

read() method returns transmit_config::R reader structure

Source

impl Readable for TRANSMIT_POSITION_SPEC

read() method returns transmit_position::R reader structure